@@ -1,10 +1,15 @@
 from restish.app import RestishApp
+from restish.templating import Templating
 
 from testish.resource import root
 
 import os, pkg_resources
 from restish.contrib.makorenderer import MakoRenderer
-
+import mimetypes
+try: 
+    mimetypes.init() 
+except AttributeError: 
+    pass 
 
 def make_app(global_conf, **app_conf):
     """
@@ -38,7 +43,7 @@ def setup_environ(app, global_conf, app_conf):
 
         # Add additional keys to the environ here. For example:
         #
-        environ['restish.templating.renderer'] = renderer
+        environ['restish.templating'] = Templating(renderer)
 
         return app(environ, start_response)
 
