@@ -34,3 +34,23 @@ class TestUtil(unittest.TestCase):
             self.assertTrue(encoded == path)
             self.assertTrue(util.decode_file_resource_path(encoded) == (name, key))
 
+class Test_classes_from_vars(unittest.TestCase):
+    def _callFUT(self, classes, include=None):
+        from formish.util import classes_from_vars
+        return classes_from_vars(classes, include)
+
+    def test_no_classes(self):
+        result = self._callFUT([])
+        self.assertEqual(result, '')
+
+    def test_classes_as_basestring(self):
+        result = self._callFUT('abc def')
+        self.assertEqual(result, ' class="abc def"')
+
+    def test_classes_as_list(self):
+        result = self._callFUT(['abc', 'def'])
+        self.assertEqual(result, ' class="abc def"')
+        
+    def test_classes_as_nested_list(self):
+        result = self._callFUT(['abc', 'def', ['ghi']])
+        self.assertEqual(result, ' class="abc def ghi"')
